@@ -4,6 +4,7 @@
 
 import os
 from labstep.generic.entity.model import Entity
+from labstep.constants import UNSPECIFIED
 
 
 class File(Entity):
@@ -25,7 +26,7 @@ class File(Entity):
 
         return fileRepository.downloadFile(self.__user__, self.id)
 
-    def save(self, folder=None, name=None):
+    def save(self, folder=UNSPECIFIED, name=UNSPECIFIED):
         """
         Save a Labstep file to the local filesystem.
 
@@ -53,10 +54,10 @@ class File(Entity):
             print('Warning: Files from External Cloud Providers cannot be downloaded')
             return
 
-        if name is None:
+        if name is UNSPECIFIED:
             name = self.name
 
-        if folder is not None:
+        if folder is not UNSPECIFIED:
             filepath = os.path.join(folder, name)
         else:
             filepath = name
